# 📰 Nudebomb News

# v0.4.0

- updated treestamps - all timestamps will miss on first run
- verbose option can be called multiple times
- quiet option
- changed colors
- uv build system

## v0.3.10

- Remove latency from progress output.

## v0.3.9

- Resolve all top paths first thing. Fixes bad symlink behavior.

## v0.3.8

- Fix crash with unresolved path and timestamps

## v0.3.7

- Add a dot color key to help.

## v0.3.6

- Fix treestamps wal file bug with illegal characters in filename.

## v0.3.5

- Require python 3.10

## v0.3.4

- Update deps.

## v0.3.3

- Upstream treestamps fixes bugs.

## v0.3.2

- Upstream treestamps returns to relative stamp paths for portability.

## v0.3.1

- Upstream treestamps fixes crashes and check_config option.

## v0.3.0

- Features

  - New ignore timestamps for one run but write them option.
  - Update deps including new treestamps.

## v0.2.6

- Features

  - Update uv.lockfile & dev deps

## v0.2.5

- Features

  - Update confuse library to latest version

## v0.2.4

- Features

  - Progress dots in non-verbose mode.

## v0.2.3

- Features

  - More output about what nudebomb is doing.
  - Renamed subs_languages config option to sub_languages.

- Fixes

  - Searching for langfiles obeys symlinks preference.

## v0.2.2

- Fixes

  - Fix timestamps factory breaking.

## v0.2.1

- Fixes

  - Timestamps respect symlinks option

## v0.2.0

- Features

  - Ignore option

## v0.1.3

- Fixes

  - Fix timestamps not recording sometimes.

## v0.1.2

- Fixes

  - Timestamps more resilient to errors.

## v0.1.1

- Fixes

  - Fix treestamps type issue.
  - Timestamps do not set on dry run.

## v0.1.0

_First Release_
